@@ -14,7 +14,9 @@ import aws_cdk.aws_s3._jsii
 import aws_cdk.core._jsii
 import constructs._jsii
 
-__jsii_assembly__ = jsii.JSIIAssembly.load("@aws-cdk/aws-glue", "1.49.1", __name__[0:-6], "aws-glue@1.49.1.jsii.tgz")
+__jsii_assembly__ = jsii.JSIIAssembly.load(
+    "@aws-cdk/aws-glue", "1.50.0", __name__[0:-6], "aws-glue@1.50.0.jsii.tgz"
+)
 
 __all__ = [
     "__jsii_assembly__",
